@@ -16,15 +16,13 @@ class GlideRecord(object):
 
     :param ServiceNowClient client: We need to know which instance we're connecting to
     :param str table: The table are we going to access
-    :param int batch_size: Batch size (items returned per HTTP request). Default is ``10``.
+    :param int batch_size: Batch size (items returned per HTTP request). Default is ``500``.
     """
-    def __init__(self, client, table, batch_size=10):
-        self._client = client
-        self.__table = table
-        self.__is_iter = False
+    def __init__(self, client, table, batch_size=500):
         self._log = logging.getLogger(__name__)
         self._client = client
         self.__table = table
+        self.__is_iter = False
         self.__batch_size = batch_size
         self.__query = Query(table)
         self.__encoded_query = None
@@ -225,13 +223,24 @@ class GlideRecord(object):
         """
         return len(self.__results) == 1 and self.__is_new_record
 
+    def set_new_guid_value(self, value):
+        """
+        This does make an assumption the guid is a sys_id, if it is not, set the value directly.
+
+        :param value: A 32 byte string that is the value
+        :return: None
+        """
+        value = str(value)
+        assert len(value) == 32, "GUID must be a 32 byte string"
+        self.sys_id = value
+
     def rewind(self):
         """
         Rewinds the record so it may be iterated upon again. Not required to be called if iterating in the pythonic method.
         """
         self.__current = -1
 
-    def query(self):
+    def query(self, query=None):
         """
         Query the table - executes a GET
 
@@ -240,7 +249,14 @@ class GlideRecord(object):
             :AuthenticationException: If we do not have rights
             :RequestException: If the transaction is canceled due to execution time
         """
-        response = self._client._list(self)
+        stored = self.__query
+        if query:
+            assert isinstance(query, Query), 'cannot query with a non query object'
+            self.__query = query
+        try:
+            response = self._client._list(self)
+        finally:
+            self.__query = stored
         code = response.status_code
         if code == 200:
             try:
